PCB Environment: Shaders Class Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions | Static Public Member Functions
Shaders Class Reference

## Public Member Functions
GLuint | load (GLenum type, const std::string &name)
bool | validate (GLuint) const
void | forget (const std::string &name)

## Static Public Member Functions
static Shaders * | getInstance ()

The documentation for this class was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/UI/Shaders.hpp